# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-09-08 11:23
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ojs', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='submission',
            name='file_object',
        ),
    ]
