{% extends "admin/base_site.html" %}
{% load i18n %}
{% block title %}{% trans "Register journals" %}{% endblock %}
{% block extrahead %}{{ block.super }}
<link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}admin/css/forms.css">
<link type="text/css" rel="stylesheet" href="{{ STATIC_URL }}css/fw-modules/alerts.css" />
<!--  Translations -->
<script type="text/javascript" src="/jsi18n/"></script>
<!-- JS error handling -->
<script type="text/javascript" src="{% url 'js-error-handler-js' %}"></script>
<!-- Underscore.js -->
<script type="text/javascript" src="{{ UNDERSCOREJS_URL }}"></script>
<!-- jQuery -->
<script type="text/javascript" src="{{ JQUERY_URL }}"></script>
<script type="text/javascript">
    window.django = {jQuery: jQuery};
</script>
<script type="text/javascript" src="{{ STATIC_URL }}admin/js/admin/RelatedObjectLookups.js"></script>
<script type="text/javascript" src="{{ STATIC_URL }}js/ojs_admin_register_journals.es5.js"></script>
{% endblock %}
{% block content %}
    <div>
        <h1>{% trans "Register journals" %}</h1>
        <p>
            {% blocktrans %}
            Register the journals from a particular OJS instance. Insert first the
            URL and Key of the OJS installation. Decide then for each journal you
            want to connect with Fidus Writer which user should be registered as
            their editor.
            {% endblocktrans %}
        </p>
        <div id="journal_form">
            <p>{% trans "URL" %}: <input type=text id="ojs_url"></p>
            <p>{% trans "Key" %}: <input type=text id="ojs_key"></p>
            <button id="get_journals">{% trans "Query available journals" %}</button>
        </div>
    </div>
{% endblock %}
